@@ -495,40 +495,40 @@ class CreateConvertTaskApiRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param ResourceId: 资源Id
-        :type ResourceId: str
         :param ResourceType: 资源类型 取值范围doc,docx,html之一
         :type ResourceType: str
-        :param ResourceName: 资源名称
+        :param ResourceName: 资源名称，长度限制为256字符
         :type ResourceName: str
-        :param Organization: 无
-        :type Organization: :class:`tencentcloud.ess.v20201111.models.OrganizationInfo`
-        :param Operator: 无
+        :param ResourceId: 资源Id，通过UploadFiles获取
+        :type ResourceId: str
+        :param Operator: 操作者信息
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param Agent: 无
+        :param Agent: 应用号信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
+        :param Organization: 暂未开放
+        :type Organization: :class:`tencentcloud.ess.v20201111.models.OrganizationInfo`
         """
-        self.ResourceId = None
         self.ResourceType = None
         self.ResourceName = None
-        self.Organization = None
+        self.ResourceId = None
         self.Operator = None
         self.Agent = None
+        self.Organization = None
 
 
     def _deserialize(self, params):
-        self.ResourceId = params.get("ResourceId")
         self.ResourceType = params.get("ResourceType")
         self.ResourceName = params.get("ResourceName")
-        if params.get("Organization") is not None:
-            self.Organization = OrganizationInfo()
-            self.Organization._deserialize(params.get("Organization"))
+        self.ResourceId = params.get("ResourceId")
         if params.get("Operator") is not None:
             self.Operator = UserInfo()
             self.Operator._deserialize(params.get("Operator"))
         if params.get("Agent") is not None:
             self.Agent = Agent()
             self.Agent._deserialize(params.get("Agent"))
+        if params.get("Organization") is not None:
+            self.Organization = OrganizationInfo()
+            self.Organization._deserialize(params.get("Organization"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -658,7 +658,7 @@ class CreateFlowByFilesRequest(AbstractModel):
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
         :param FlowName: 签署流程名称,最大长度200个字符
         :type FlowName: str
-        :param Approvers: 签署参与者信息
+        :param Approvers: 签署参与者信息，最大限制50方
         :type Approvers: list of ApproverInfo
         :param FileIds: 签署pdf文件的资源编号列表，通过UploadFiles接口获取
         :type FileIds: list of str
@@ -684,6 +684,11 @@ false：有序签
         :type Unordered: bool
         :param CustomShowMap: 合同显示的页卡模板，说明：只支持{合同名称}, {发起方企业}, {发起方姓名}, {签署方N企业}, {签署方N姓名}，且N不能超过签署人的数量，N从1开始
         :type CustomShowMap: str
+        :param NeedSignReview: 发起方企业的签署人进行签署操作是否需要企业内部审批。
+若设置为true,审核结果需通过接口 CreateFlowSignReview 通知电子签，审核通过后，发起方企业签署人方可进行签署操作，否则会阻塞其签署操作。
+
+注：企业可以通过此功能与企业内部的审批流程进行关联，支持手动、静默签署合同。
+        :type NeedSignReview: bool
         :param Agent: 应用号信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
         """
@@ -699,6 +704,7 @@ false：有序签
         self.Deadline = None
         self.Unordered = None
         self.CustomShowMap = None
+        self.NeedSignReview = None
         self.Agent = None
 
 
@@ -732,6 +738,7 @@ false：有序签
         self.Deadline = params.get("Deadline")
         self.Unordered = params.get("Unordered")
         self.CustomShowMap = params.get("CustomShowMap")
+        self.NeedSignReview = params.get("NeedSignReview")
         if params.get("Agent") is not None:
             self.Agent = Agent()
             self.Agent._deserialize(params.get("Agent"))
@@ -781,7 +788,7 @@ class CreateFlowRequest(AbstractModel):
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
         :param FlowName: 签署流程名称,最大长度200个字符
         :type FlowName: str
-        :param Approvers: 签署流程参与者信息
+        :param Approvers: 签署流程参与者信息，最大限制50方
         :type Approvers: list of FlowCreateApprover
         :param FlowType: 签署流程的类型(如销售合同/入职合同等)，最大长度200个字符
         :type FlowType: str
@@ -803,6 +810,11 @@ false：有序签
         :type Unordered: bool
         :param CustomShowMap: 合同显示的页卡模板，说明：只支持{合同名称}, {发起方企业}, {发起方姓名}, {签署方N企业}, {签署方N姓名}，且N不能超过签署人的数量，N从1开始
         :type CustomShowMap: str
+        :param NeedSignReview: 发起方企业的签署人进行签署操作是否需要企业内部审批。
+若设置为true,审核结果需通过接口 CreateFlowSignReview 通知电子签，审核通过后，发起方企业签署人方可进行签署操作，否则会阻塞其签署操作。
+
+注：企业可以通过此功能与企业内部的审批流程进行关联，支持手动、静默签署合同。
+        :type NeedSignReview: bool
         :param RelatedFlowId: 暂未开放
         :type RelatedFlowId: str
         :param Agent: 应用相关信息
@@ -819,6 +831,7 @@ false：有序签
         self.FlowDescription = None
         self.Unordered = None
         self.CustomShowMap = None
+        self.NeedSignReview = None
         self.RelatedFlowId = None
         self.Agent = None
 
@@ -842,6 +855,7 @@ false：有序签
         self.FlowDescription = params.get("FlowDescription")
         self.Unordered = params.get("Unordered")
         self.CustomShowMap = params.get("CustomShowMap")
+        self.NeedSignReview = params.get("NeedSignReview")
         self.RelatedFlowId = params.get("RelatedFlowId")
         if params.get("Agent") is not None:
             self.Agent = Agent()
@@ -876,6 +890,70 @@ class CreateFlowResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class CreateFlowSignReviewRequest(AbstractModel):
+    """CreateFlowSignReview请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Operator: 调用方用户信息，userId 必填
+        :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
+        :param FlowId: 签署流程编号
+        :type FlowId: str
+        :param ReviewType: 企业内部审核结果
+PASS: 通过 
+REJECT: 拒绝
+        :type ReviewType: str
+        :param ReviewMessage: 审核原因 
+当ReviewType 是REJECT 时此字段必填,字符串长度不超过200
+        :type ReviewMessage: str
+        :param Agent: 应用相关信息
+        :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
+        """
+        self.Operator = None
+        self.FlowId = None
+        self.ReviewType = None
+        self.ReviewMessage = None
+        self.Agent = None
+
+
+    def _deserialize(self, params):
+        if params.get("Operator") is not None:
+            self.Operator = UserInfo()
+            self.Operator._deserialize(params.get("Operator"))
+        self.FlowId = params.get("FlowId")
+        self.ReviewType = params.get("ReviewType")
+        self.ReviewMessage = params.get("ReviewMessage")
+        if params.get("Agent") is not None:
+            self.Agent = Agent()
+            self.Agent._deserialize(params.get("Agent"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateFlowSignReviewResponse(AbstractModel):
+    """CreateFlowSignReview返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class CreateMultiFlowSignQRCodeRequest(AbstractModel):
     """CreateMultiFlowSignQRCode请求参数结构体
 
@@ -1166,7 +1244,7 @@ class DescribeFlowBriefsRequest(AbstractModel):
         r"""
         :param Operator: 调用方用户信息，userId 必填
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param FlowIds: 需要查询的流程ID列表
+        :param FlowIds: 需要查询的流程ID列表，限制最大20个
         :type FlowIds: list of str
         :param Agent: 应用相关信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
@@ -1230,7 +1308,7 @@ class DescribeFlowTemplatesRequest(AbstractModel):
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
         :param Filters: 搜索条件，具体参考Filter结构体。本接口取值：template-id：按照【 **模板唯一标识** 】进行过滤
         :type Filters: list of Filter
-        :param Limit: 查询个数，默认20，最大100
+        :param Limit: 查询个数，默认20，最大200
         :type Limit: int
         :param Offset: 查询偏移位置，默认0
         :type Offset: int
@@ -1630,32 +1708,32 @@ class GetTaskResultApiRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param TaskId: 任务Id
+        :param TaskId: 任务Id，通过CreateConvertTaskApi得到
         :type TaskId: str
-        :param Organization: 企业信息
-        :type Organization: :class:`tencentcloud.ess.v20201111.models.OrganizationInfo`
         :param Operator: 操作人信息
         :type Operator: :class:`tencentcloud.ess.v20201111.models.UserInfo`
-        :param Agent: 渠道信息
+        :param Agent: 应用号信息
         :type Agent: :class:`tencentcloud.ess.v20201111.models.Agent`
+        :param Organization: 暂未开放
+        :type Organization: :class:`tencentcloud.ess.v20201111.models.OrganizationInfo`
         """
         self.TaskId = None
-        self.Organization = None
         self.Operator = None
         self.Agent = None
+        self.Organization = None
 
 
     def _deserialize(self, params):
         self.TaskId = params.get("TaskId")
-        if params.get("Organization") is not None:
-            self.Organization = OrganizationInfo()
-            self.Organization._deserialize(params.get("Organization"))
         if params.get("Operator") is not None:
             self.Operator = UserInfo()
             self.Operator._deserialize(params.get("Operator"))
         if params.get("Agent") is not None:
             self.Agent = Agent()
             self.Agent._deserialize(params.get("Agent"))
+        if params.get("Organization") is not None:
+            self.Organization = OrganizationInfo()
+            self.Organization._deserialize(params.get("Organization"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1674,11 +1752,23 @@ class GetTaskResultApiResponse(AbstractModel):
         r"""
         :param TaskId: 任务Id
         :type TaskId: str
-        :param TaskStatus: 任务状态
+        :param TaskStatus: 任务状态，需要关注的状态
+0  :NeedTranform   - 任务已提交
+4  :Processing     - 文档转换中
+8  :TaskEnd        - 任务处理完成
+-2 :DownloadFailed - 下载失败
+-6 :ProcessFailed  - 转换失败
+-13:ProcessTimeout - 转换文件超时
         :type TaskStatus: int
-        :param TaskMessage: 状态描述
+        :param TaskMessage: 状态描述，需要关注的状态
+NeedTranform   - 任务已提交
+Processing     - 文档转换中
+TaskEnd        - 任务处理完成
+DownloadFailed - 下载失败
+ProcessFailed  - 转换失败
+ProcessTimeout - 转换文件超时
         :type TaskMessage: str
-        :param ResourceId: 资源Id
+        :param ResourceId: 资源Id，也是FileId，用于文件发起使用
         :type ResourceId: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -2069,8 +2159,8 @@ class UploadFilesRequest(AbstractModel):
     def __init__(self):
         r"""
         :param BusinessType: 文件对应业务类型，用于区分文件存储路径：
-1. TEMPLATE - 模板； 文件类型：.pdf/.html
-2. DOCUMENT - 签署过程及签署后的合同文档 文件类型：.pdf/.html
+1. TEMPLATE - 模板； 文件类型：.pdf .doc .docx .html
+2. DOCUMENT - 签署过程及签署后的合同文档/图片控件 文件类型：.pdf/.jpg/.png
 3. SEAL - 印章； 文件类型：.jpg/.jpeg/.png
         :type BusinessType: str
         :param Caller: 调用方信息
